@@ -14,10 +14,14 @@ use std::time::Instant;
 use std::io::{Write, ErrorKind};
 use mlua::Lua;
 
+mod mouse;
+
 /// For managing all editing and rendering of cactus
 pub struct Editor {
     /// Interface for writing to the terminal
     pub terminal: Terminal,
+    /// Whether to rerender the editor on the next cycle
+    pub needs_rerender: bool,
     /// Configuration information for the editor
     pub config: Config,
     /// Storage of all the documents opened in the editor
@@ -43,14 +47,16 @@ pub struct Editor {
 impl Editor {
     /// Create a new instance of the editor
     pub fn new(lua: &Lua) -> Result<Self> {
+        let config = Config::new(lua)?;
         Ok(Self {
             doc: vec![],
             ptr: 0,
-            terminal: Terminal::new(),
-            config: Config::new(lua)?,
+            terminal: Terminal::new(config.terminal.clone()),
+            config,
             active: true,
             greet: false,
             help: false,
+            needs_rerender: true,
             highlighter: vec![],
             feedback: Feedback::None,
             command: None,
@@ -199,7 +205,15 @@ impl Editor {
         // Run the editor
         self.render()?;
         // Wait for an event
-        match read()? {
+        let event = read()?;
+        self.needs_rerender = match event {
+            CEvent::Mouse(event) => match event.kind {
+                crossterm::event::MouseEventKind::Moved => false,
+                _ => true,
+            },
+            _ => true,
+        };
+        match event {
             CEvent::Key(key) => {
                 // Check period of inactivity and commit events (for undo/redo) if over 10secs
                 let end = Instant::now();
@@ -234,6 +248,10 @@ impl Editor {
                     self.doc_mut().move_home();
                 }
             }
+            CEvent::Mouse(mouse_event) => {
+                self.handle_mouse_event(mouse_event);
+                return Ok(None);
+            }
             _ => (),
         }
         self.feedback = Feedback::None;
@@ -258,6 +276,10 @@ impl Editor {
 
     /// Render a single frame of the editor in it's current state
     pub fn render(&mut self) -> Result<()> {
+        if !self.needs_rerender {
+            return Ok(());
+        }
+        self.needs_rerender = false;
         self.terminal.hide_cursor()?;
         let Size { w, mut h } = size()?;
         h = h.saturating_sub(2);
@@ -340,6 +362,12 @@ impl Editor {
         Ok(())
     }
 
+    fn render_document_tab_header(&self, document: &Document) -> String {
+        let file_name = document.file_name.clone().unwrap_or_else(|| "[No Name]".to_string());
+        let modified = if document.modified { "[+]" } else { "" };
+        format!("  {file_name}{modified}  ")
+    }
+
     /// Render the tab line at the top of the document
     fn render_tab_line(&mut self, w: usize) -> Result<()> {
         self.terminal.prepare_line(0)?;
@@ -350,13 +378,12 @@ impl Editor {
             Bg(self.config.colors.borrow().tab_inactive_bg.to_color()?)
         )?;
         for (c, document) in self.doc.iter().enumerate() {
-            let file_name = document.file_name.clone().unwrap_or_else(|| "[No Name]".to_string());
-            let modified = if document.modified { "[+]" } else { "" };
+            let document_header = self.render_document_tab_header(document);
             if c == self.ptr {
                 // Representing the document we're currently looking at
                 write!(
                     self.terminal.stdout, 
-                    "{}{}{}  {file_name}{modified}  {}{}{}│",
+                    "{}{}{}{document_header}{}{}{}│",
                     Bg(self.config.colors.borrow().tab_active_bg.to_color()?),
                     Fg(self.config.colors.borrow().tab_active_fg.to_color()?),
                     SetAttribute(Attribute::Bold),
@@ -366,7 +393,7 @@ impl Editor {
                 )?;
             } else {
                 // Other document that is currently open
-                write!(self.terminal.stdout, "  {file_name}{modified}  │")?;
+                write!(self.terminal.stdout, "{document_header}│")?;
             }
         }
         write!(self.terminal.stdout, "{}", " ".to_string().repeat(w))?;
