@@ -1,14 +1,16 @@
-use crate::config::Colors;
+use crate::config::{Colors, TerminalConfig};
 use crate::error::Result;
 use crossterm::{
-    cursor::{Hide, MoveTo, Show},
-    execute,
-    style::{SetBackgroundColor as Bg, SetForegroundColor as Fg, SetAttribute, Attribute},
-    terminal::{self, Clear, ClearType as ClType, EnterAlternateScreen, LeaveAlternateScreen, EnableLineWrap, DisableLineWrap},
-    event::{PushKeyboardEnhancementFlags, KeyboardEnhancementFlags},
+    cursor::{Hide, MoveTo, Show}, 
+    event::{EnableMouseCapture, DisableMouseCapture, KeyboardEnhancementFlags, PushKeyboardEnhancementFlags}, 
+    execute, 
+    style::{Attribute, SetAttribute, SetBackgroundColor as Bg, SetForegroundColor as Fg}, 
+    terminal::{self, Clear, ClearType as ClType, DisableLineWrap, EnableLineWrap, EnterAlternateScreen, LeaveAlternateScreen}
 };
-use kaolinite::utils::{Size};
+use kaolinite::utils::Size;
+use std::cell::RefCell;
 use std::io::{stdout, Stdout, Write};
+use std::rc::Rc;
 
 /// Constant that shows the help message
 pub const HELP_TEXT: &str = "
@@ -84,12 +86,14 @@ impl Feedback {
 
 pub struct Terminal {
     pub stdout: Stdout,
+    pub config: Rc<RefCell<TerminalConfig>>,
 }
 
 impl Terminal {
-    pub fn new() -> Self {
+    pub fn new(config: Rc<RefCell<TerminalConfig>>) -> Self {
         Terminal {
             stdout: stdout(),
+            config,
         }
     }
 
@@ -101,6 +105,9 @@ impl Terminal {
             eprintln!("{}", e);
         }));
         execute!(self.stdout, EnterAlternateScreen, Clear(ClType::All), DisableLineWrap)?;
+        if self.config.borrow().mouse_enabled {
+            execute!(self.stdout, EnableMouseCapture)?;    
+        }
         terminal::enable_raw_mode()?;
         execute!(
             self.stdout,
@@ -115,6 +122,9 @@ impl Terminal {
     pub fn end(&mut self) -> Result<()> {
         terminal::disable_raw_mode()?;
         execute!(self.stdout, LeaveAlternateScreen, EnableLineWrap)?;
+        if self.config.borrow().mouse_enabled {
+            execute!(self.stdout, DisableMouseCapture)?;    
+        }
         Ok(())
     }
 
